//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by Celestia.rc
//
#define IDR_MENU1                       101
#define IDD_ABOUT                       102
#define IDI_CELESTIA_ICON               103
#define IDD_FINDOBJECT                  104
#define IDR_MAIN_MENU                   105
#define IDR_ACCELERATORS                106
#define IDD_LICENSE                     108
#define IDD_SETTIME                     109
#define IDD_GLINFO                      110
#define IDD_ADDLOCATION                 111
#define IDD_SSBROWSER                   112
#define IDD_STARBROWSER                 113
#define IDD_TOURGUIDE                   114
#define IDD_CONTROLSHELP                115
#define IDD_GOTO_OBJECT                 116
#define IDD_MOVIE_PARAMS_CHOOSER        117
#define IDD_DISPLAYMODE                 118
#define IDD_VIEWOPTIONS                 119
#define IDI_LOCATION                    123
#define IDI_CLOSEDFOLDER                125
#define IDI_OPENFOLDER                  126
#define IDI_ROOTFOLDER                  127
#define IDD_ADDLOCATION_FOLDER          128
#define IDD_ORGANIZE_LOCATIONS          129
#define IDD_RENAME_LOCATION             130
#define IDD_COMPUTEECLIPSES             131
#define IDD_ECLIPSEFINDER               132
#define IDB_FOLDERCLOSED                532
#define IDB_FOLDEROPENED                534
#define IDB_LOCATION                    536
#define IDB_CAMERA                      537
#define IDB_CAMCORDER                   538
#define IDB_SCRIPT                      539
#define IDB_CLOCK                       540
#define IDC_FINDOBJECT_EDIT             1001
#define IDC_LICENSE_TEXT                1004
#define IDC_GLINFO_TEXT                 1005
#define IDC_CALENDAR                    1006
#define IDC_TIMEPICKER                  1007
#define IDC_DATEPICKER                  1008
#define IDC_LOCATION_EDIT               1009
#define IDC_SSBROWSER_TREE              1010
#define IDC_BUTTON_CENTER               1011
#define IDC_BUTTON_GOTO                 1012
#define IDC_STARBROWSER_LIST            1013
#define IDC_BUTTON_REFRESH              1014
#define IDC_RADIO_NEAREST               1015
#define IDC_RADIO_BRIGHTEST             1016
#define IDC_RADIO_WITHPLANETS           1017
#define IDC_COMBO_TOURGUIDE             1018
#define IDC_TEXT_DESCRIPTION            1019
#define IDC_TEXT_CONTROLSHELP           1020
#define IDC_EDIT_OBJECTNAME             1021
#define IDC_EDIT_LONGITUDE              1022
#define IDC_EDIT_LATITUDE               1023
#define IDC_EDIT_DISTANCE               1024
#define IDC_RADIO_KM                    1025
#define IDC_RADIO_AU                    1026
#define IDC_RADIO_RADII                 1027
#define IDC_SETCURRENTTIME              1028
#define IDC_COMBO_MOVIE_SIZE            1029
#define IDC_COMBO_MOVIE_FRAMERATE       1030
#define IDC_MAXSTARS_SLIDER             1031
#define IDC_MAXSTARS_EDIT               1032
#define IDC_COMBO_RESOLUTION            1033
#define IDC_SHOWGALAXIES                1034
#define IDC_SHOWATMOSPHERES             1035
#define IDC_SHOWCLOUDS                  1036
#define IDC_SHOWORBITS                  1037
#define IDC_SHOWCONSTELLATIONS          1038
#define IDC_SHOWCELESTIALGRID           1039
#define IDC_SHOWNIGHTSIDELIGHTS         1040
#define IDC_SHOWPLANETS                 1041
#define IDC_SHOWSTARS                   1042
#define IDC_SHOWECLIPSESHADOWS          1043
#define IDC_LABELPLANETS                1044
#define IDC_LABELMOONS                  1045
#define IDC_LABELSTARS                  1046
#define IDC_LABELCONSTELLATIONS         1047
#define IDC_LABELGALAXIES               1048
#define IDC_INFOTEXT0                   1049
#define IDC_INFOTEXT1                   1050
#define IDC_INFOTEXT2                   1051
#define IDC_LOCATION_CREATEIN           1052
#define IDC_LOCATION_NEWFOLDER          1053
#define IDC_LOCATION_FOLDERTREE         1054
#define IDC_LOCATIONFOLDER              1057
#define IDC_ORGANIZE_LOCATION_TREE      1058
#define IDC_ORGANIZE_LOCATIONS_NEWFOLDER 1059
#define IDC_ORGANIZE_LOCATIONS_RENAME   1060
#define IDC_ORGANIZE_LOCATIONS_DELETE   1061
#define IDC_NEWLOCATION                 1062
#define IDC_SHOWSTARSASPOINTS           1063
#define IDC_LABELASTEROIDS              1064
#define IDC_LABELSPACECRAFT             1065
#define IDC_ECLIPSES_LIST               1071
#define IDCOMPUTE                       1078
#define IDC_DATEFROM                    1079
#define IDC_ECLIPSEFROM                 1079
#define IDC_DATETO                      1080
#define IDC_ECLIPSETO                   1080
#define IDSETDATEANDGO                  1081
#define IDC_EDIT_FILTER_DISTANCE        1084
#define IDC_SLIDER_FILTER_DISTANCE      1085
#define IDC_SHOWCOMETTAILS              1086
#define IDC_SHOWCONSTELLATIONBORDERS    1087
#define IDC_SHOWRINGSHADOWS             1088
#define IDC_ECLIPSETYPE                 1089
#define IDC_ECLIPSETARGET               1090
#define ID_SELECTSOL                    40001
#define ID_GOTOSELECTION                40002
#define ID_FOLLOWSELECTION              40003
#define ID_SPEEDTIME                    40005
#define ID_SLOWTIME                     40006
#define ID_STOPTIME                     40007
#define ID_QUIT                         40008
#define ID_FILE_EXIT                    40009
#define ID_HELP_ABOUT                   40010
#define ID_RENDER_AMBIENTLIGHT_NONE     40014
#define ID_RENDER_AMBIENTLIGHT_LOW      40015
#define ID_RENDER_AMBIENTLIGHT_MEDIUM   40016
#define ID_RENDER_PIXEL_SHADERS         40017
#define ID_NAVIGATION_HOME              40018
#define ID_NAVIGATION_SELECT            40019
#define ID_NAVIGATION_GOTO              40020
#define ID_NAVIGATION_FOLLOW            40021
#define ID_NAVIGATION_TOURGUIDE         40022
#define ID_NAVIGATION_ECLIPSEFINDER     40023
#define ID_TIME_FASTER                  40024
#define ID_TIME_SLOWER                  40025
#define ID_TIME_FREEZE                  40026
#define ID_TIME_REVERSE                 40027
#define ID_HELP_LICENSE                 40028
#define ID_NAVIGATION_CENTER            40029
#define ID_TIME_REALTIME                40030
#define ID_TIME_SETTIME                 40032
#define ID_HELP_GLINFO                  40033
#define ID_LOCATIONS_ADDLOCATION        40034
#define ID_INFO                         40040
#define ID_HELP_RUNDEMO                 40041
#define ID_RENDER_MORESTARS             40042
#define ID_RENDER_FEWERSTARS            40043
#define ID_NAVIGATION_SYNCORBIT         40045
#define ID_NAVIGATION_SSBROWSER         40046
#define ID_NAVIGATION_STARBROWSER       40047
#define ID_TIME_SHOWLOCAL               40050
#define ID_NAVIGATION_TRACK             40051
#define ID_HELP_CONTROLS                40053
#define ID_RENDER_VERTEX_SHADERS        40055
#define ID_NAVIGATION_GOTO_OBJECT       40056
#define ID_FILE_CAPTUREIMAGE            40057
#define ID_FILE_CAPTUREMOVIE            40058
#define ID_RENDER_DISPLAYMODE           40059
#define ID_RENDER_FULLSCREEN            40060
#define ID_RENDER_VIEWOPTIONS           40061
#define ID_RENDER_ANTIALIASING          40062
#define ID_LOCATIONS_ORGANIZE           40063
#define ID_FILE_OPENSCRIPT              40064
#define ID_TOOLS_MARK                   40065
#define ID_TOOLS_UNMARK                 40066
#define ID_VIEW_HSPLIT                  40067
#define ID_VIEW_VSPLIT                  40068
#define ID_VIEW_DELETE_ACTIVE           40069
#define ID_VIEW_SINGLE                  40070
#define ID_VIEW_SHOW_FRAMES             40071
#define ID_VIEW_SYNC_TIME               40072
#define ID_LOCATIONS_FIRSTLOCATION      41000

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        134
#define _APS_NEXT_COMMAND_VALUE         40065
#define _APS_NEXT_CONTROL_VALUE         1091
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
